'use strict';

var assert = require('uvu/assert');
var web3_storage = require('web3.storage');

function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () {
            return e[k];
          }
        });
      }
    });
  }
  n['default'] = e;
  return Object.freeze(n);
}

var assert__namespace = /*#__PURE__*/_interopNamespace(assert);

/* eslint-env mocha */

describe('get', () => {
  const { AUTH_TOKEN, API_PORT } = process.env;
  const token = AUTH_TOKEN || 'good';
  const endpoint = new URL(API_PORT ? `http://localhost:${API_PORT}` : '');

  it('get a CAR', async () => {
    const client = new web3_storage.Web3Storage({ token, endpoint });
    const cid = 'bafkreifzjut3te2nhyekklss27nh3k72ysco7y32koao5eei66wof36n5e';
    const res = await client.get(cid);
    assert__namespace.ok(res.ok);
    const blob = await res.blob();
    assert__namespace.is(
      blob.type,
      'application/car',
      `car type should be set correctly ${blob.type}`
    );
  });

  it('get files', async () => {
    const client = new web3_storage.Web3Storage({ token, endpoint });
    const cid = 'bafkreifzjut3te2nhyekklss27nh3k72ysco7y32koao5eei66wof36n5e';
    const res = await client.get(cid);
    assert__namespace.ok(res.ok);
    const files = await res.files();
    for (const file of files) {
      assert__namespace.is(
        file.cid,
        cid,
        'in a CAR with 1 file, the file name should match the CAR root'
      );
      assert__namespace.is(
        file.name,
        cid,
        `name (${file.name}) should be (${cid})`
      );
      assert__namespace.ok(file.lastModified);
      assert__namespace.is(await file.text(), 'hello world');
    }
    assert__namespace.is(files.length, 1, 'should contain 1 file');
  });

  it('get dirs', async () => {
    const client = new web3_storage.Web3Storage({ token, endpoint });
    const cid = 'bafybeidd2gyhagleh47qeg77xqndy2qy3yzn4vkxmk775bg2t5lpuy7pcu';
    const res = await client.get(cid);
    assert__namespace.ok(res.ok);
    const files = await res.files();
    assert__namespace.is(files.length, 3, 'should contain 3 files');
    assert__namespace.is(files[0].name, 'dr-is-tired.jpg');
    assert__namespace.is(files[0].cid, 'bafkreiabltrd5zm73pvi7plq25pef3hm7jxhbi3kv4hapegrkfpkqtkbme');
    assert__namespace.is(files[0].size, 94482);
    assert__namespace.is(files[1].name, 'not-distributed.jpg');
    assert__namespace.is(files[1].cid, 'bafybeicklkqcnlvtiscr2hzkubjwnwjinvskffn4xorqeduft3wq7vm5u4');
    assert__namespace.is(files[1].size, 414201);
    assert__namespace.is(files[2].name, 'youareanonsense.jpg');
    assert__namespace.is(files[2].cid, 'bafkreiaqv66m5nd6mwgkk7h5lwqnjzj54s4f7knmnrjhb7ylzqfg2vdo54');
    assert__namespace.is(files[2].size, 55415);
  });

  it('returns null on 404', async () => {
    const client = new web3_storage.Web3Storage({ token, endpoint });
    const cid = 'bafkreieq5jui4j25lacwomsqgjeswwl3y5zcdrresptwgmfylxo2depppq';
    const res = await client.get(cid);
    assert__namespace.not.ok(res, 'res should be null');
  });

  it('throws on invalid cid', async () => {
    const client = new web3_storage.Web3Storage({ token, endpoint });
    const cid = 'bafkreieq';
    try {
      await client.get(cid);
      assert__namespace.unreachable('sholud have thrown');
    } catch (err) {
      assert__namespace.match(err, /400/);
    }
  });
});
//# sourceMappingURL=get.spec.cjs.map
