'use strict';

var assert = require('uvu/assert');
var randomBytes = require('randombytes');
var web3_storage = require('web3.storage');
require('@web-std/fetch');
require('@web-std/blob');
var file = require('@web-std/file');
require('ipfs-car/blockstore/fs');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () {
            return e[k];
          }
        });
      }
    });
  }
  n['default'] = e;
  return Object.freeze(n);
}

var assert__namespace = /*#__PURE__*/_interopNamespace(assert);
var randomBytes__default = /*#__PURE__*/_interopDefaultLegacy(randomBytes);

/* eslint-env mocha */

describe('put', () => {
  const { AUTH_TOKEN, API_PORT } = process.env;
  const token = AUTH_TOKEN || 'good';
  const endpoint = new URL(API_PORT ? `http://localhost:${API_PORT}` : '');

  it('errors without token', async () => {
    // @ts-ignore
    const client = new web3_storage.Web3Storage({ endpoint });
    const files = prepareFiles();
    try {
      await client.put(files);
      assert__namespace.unreachable('should have thrown');
    } catch (err) {
      assert__namespace.is(err.message, 'missing token');
    }
  });

  it('errors without content', async () => {
    const client = new web3_storage.Web3Storage({ endpoint, token });
    try {
      await client.put([]);
      assert__namespace.unreachable('should have thrown');
    } catch (err) {
      assert__namespace.match(err.message, /missing input file/);
    }
  });

  it('erros with a File that will not be parsed by the Cluster', async function () {
    const client = new web3_storage.Web3Storage({ token, endpoint });
    try {
      await client.put([new file.File(['test-put-fail'], 'file.txt')], { maxRetries: 1 });
      assert__namespace.unreachable('should have thrown');
    } catch (err) {
      assert__namespace.match(err.message, /Request body not a valid CAR file/);
    }
  });

  it('adds Files', async () => {
    const client = new web3_storage.Web3Storage({ token, endpoint });
    const files = prepareFiles();
    const expectedCid = 'bafybeiep3t2chy6e3dxk3fktnshm7tpopjrns6wevo4uwpnnz5aq352se4';
    const cid = await client.put(files, {
      name: 'web3-storage-dir',
      onRootCidReady: (cid) => {
        assert__namespace.equal(cid, expectedCid, 'returned cid matches the CAR');
      }
    });
    assert__namespace.equal(cid, expectedCid, 'returned cid matches the CAR');
  });

  it('adds Big Files', async function () {
    this.timeout(30e3);
    const client = new web3_storage.Web3Storage({ token, endpoint });
    let uploadedChunks = 0;

    const files = [
      new file.File([randomBytes__default['default'](1024e6)], '102mb.txt')
    ];

    await client.put(files, {
      onStoredChunk: () => {
        uploadedChunks++;
      }
    });
    assert__namespace.ok(uploadedChunks >= 100);
  });
});

function prepareFiles () {
  const data = 'Hello web3.storage!';
  const data2 = 'Hello web3.storage!!';

  return [
    new file.File(
      [data],
      '/dir/data.txt'
    ),
    new file.File(
      [data2],
      '/dir/data2.txt'
    ),
    new file.File(
      [data],
      '/dir/otherdir/data.txt'
    ),
    new file.File(
      [data2],
      '/dir/otherdir/data2.txt'
    )
  ]
}
//# sourceMappingURL=put.spec.cjs.map
