'use strict';

var assert = require('uvu/assert');
var web3_storage = require('web3.storage');

function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () {
            return e[k];
          }
        });
      }
    });
  }
  n['default'] = e;
  return Object.freeze(n);
}

var assert__namespace = /*#__PURE__*/_interopNamespace(assert);

/* eslint-env mocha */

describe('status', () => {
  const { AUTH_TOKEN, API_PORT } = process.env;
  const token = AUTH_TOKEN || 'good';
  const endpoint = new URL(API_PORT ? `http://localhost:${API_PORT}` : '');

  it('returns an object', async () => {
    const client = new web3_storage.Web3Storage({ token, endpoint });
    const cid = 'bafkreifzjut3te2nhyekklss27nh3k72ysco7y32koao5eei66wof36n5e';
    const status = await client.status(cid);
    assert__namespace.is(status.cid, cid);
    assert__namespace.ok(status.dagSize);
    assert__namespace.ok(status.created);
    assert__namespace.ok(status.deals);
    assert__namespace.ok(status.pins);
  });

  it('returns undefined on 404', async () => {
    const client = new web3_storage.Web3Storage({ token, endpoint });
    const cid = 'unknown';
    const status = await client.status(cid);
    assert__namespace.is(status, undefined);
  });

  it('throws on error', async () => {
    const client = new web3_storage.Web3Storage({ token, endpoint });
    const cid = 'error';
    try {
      await client.status(cid);
      assert__namespace.unreachable();
    } catch (err) {
      assert__namespace.is(err.message, 'Internal Server Error');
    }
  });
});
//# sourceMappingURL=status.spec.cjs.map
